--
-- Knights "Multiwand" mod
--
-- Originally by ImpassIve_rus
-- Adapted for latest version of Knights by Stephen Thompson
--
-- See:
-- http://www.knightsgame.org.uk/forum/index.php?topic=199.0
--
-- This makes the following additions to Knights:
--
--  1) Wands are colour coded as follows:
--   a) Wand of destruction = red
--   b) Wand of securing = light blue
--   c) Wand of open ways = white
--   d) Wand of undeath = dark brown
--
--  2) An option "All wands" is added to the main menu, under "Type of
--     Wand".
--
-- To use:
--
--  1) Copy the "multiwand" folder into your knights_data/server/ directory.
--  2) Add require("multiwand") to knights_data/main.lua (at the bottom).


-- Implementation follows.
module(...)

-- Open "classic" and "menu" modules
local C = require("classic")
local M = require("menu")

-- First load the new wand graphics
g_wand_dest = kts.Graphic("wands/dest.bmp",0,0,0,-3,-6)
g_wand_secu = kts.Graphic("wands/secu.bmp",0,0,0,-3,-6)
g_wand_open = kts.Graphic("wands/open.bmp",0,0,0,-3,-6)
g_wand_deat = kts.Graphic("wands/deat.bmp",0,0,0,-3,-6)

g_wand_dest_north = kts.Graphic("wands/dest_north.bmp",0,0,0, -6,-5)
g_wand_dest_east  = kts.Graphic("wands/dest_east.bmp",0,0,0,   0,-6)
g_wand_dest_south = kts.Graphic("wands/dest_south.bmp",0,0,0, -7, 0)
g_wand_dest_west  = kts.Graphic("wands/dest_west.bmp",0,0,0,  -5,-7)
g_wand_secu_north = kts.Graphic("wands/secu_north.bmp",0,0,0, -6,-5)
g_wand_secu_east  = kts.Graphic("wands/secu_east.bmp",0,0,0,   0,-6)
g_wand_secu_south = kts.Graphic("wands/secu_south.bmp",0,0,0, -7, 0)
g_wand_secu_west  = kts.Graphic("wands/secu_west.bmp",0,0,0,  -5,-7)
g_wand_open_north = kts.Graphic("wands/open_north.bmp",0,0,0, -6,-5)
g_wand_open_east  = kts.Graphic("wands/open_east.bmp",0,0,0,   0,-6)
g_wand_open_south = kts.Graphic("wands/open_south.bmp",0,0,0, -7, 0)
g_wand_open_west  = kts.Graphic("wands/open_west.bmp",0,0,0,  -5,-7)
g_wand_deat_north = kts.Graphic("wands/deat_north.bmp",0,0,0, -6,-5)
g_wand_deat_east  = kts.Graphic("wands/deat_east.bmp",0,0,0,   0,-6)
g_wand_deat_south = kts.Graphic("wands/deat_south.bmp",0,0,0, -7, 0)
g_wand_deat_west  = kts.Graphic("wands/deat_west.bmp",0,0,0,  -5,-7)

-- Create overlays
o_wand_dest = kts.Overlay{ g_wand_dest_north, 
                           g_wand_dest_east,
                           g_wand_dest_south,
                           g_wand_dest_west }
o_wand_secu = kts.Overlay{ g_wand_secu_north,
                           g_wand_secu_east,
                           g_wand_secu_south,
                           g_wand_secu_west }
o_wand_open = kts.Overlay{ g_wand_open_north,
                           g_wand_open_east,
                           g_wand_open_south,
                           g_wand_open_west }
o_wand_deat = kts.Overlay{ g_wand_deat_north,
                           g_wand_deat_east,
                           g_wand_deat_south,
                           g_wand_deat_west }

-- Modify the existing wand types in-place.
C.i_wand_of_destruction.graphic = g_wand_dest
C.i_wand_of_destruction.overlay = o_wand_dest
C.i_wand_of_securing.graphic = g_wand_secu
C.i_wand_of_securing.overlay = o_wand_secu
C.i_wand_of_open_ways.graphic = g_wand_open
C.i_wand_of_open_ways.overlay = o_wand_open
C.i_wand_of_undeath.graphic = g_wand_deat
C.i_wand_of_undeath.overlay = o_wand_deat

-- Add new options to the menu: "Multiple Wands" and "All Wands"

new_choice_1 = {
   id = "multi_wands",
   text = "Multiple Wands",
   features = function(S)
      M.get_menu_choice("wand", "destruction").features (S)
      M.get_menu_choice("wand", "securing")   .features (S)
   end
}

new_choice_2 = {
   id = "all_wands",
   text = "All Wands",
   features = function(S)
      M.get_menu_choice("wand", "destruction").features (S)
      M.get_menu_choice("wand", "securing")   .features (S)
      M.get_menu_choice("wand", "open_ways")  .features (S)
      M.get_menu_choice("wand", "undeath")    .features (S)
   end
}
      
M.add_menu_choice("wand", new_choice_1)
M.add_menu_choice("wand", new_choice_2)